Standing loss proportional to stored energy each time step.
Usage
get_storage_losses(power, loss, time_resolution = 60)
Arguments
- power
numeric vector, being positive when charging and negative when discharging
- loss
numeric, the hourly storage loss in percentage (%/hour)
- time_resolution
numeric, time resolution of the time-series (in minutes)